hstrat.hstrat.HereditaryStratum
===============================

.. currentmodule:: hstrat.hstrat

.. autoclass:: HereditaryStratum

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~HereditaryStratum.GetAnnotation
      ~HereditaryStratum.GetDepositionRank
      ~HereditaryStratum.GetDifferentia
      ~HereditaryStratum.__init__
   
   

   
   
   